<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


require_once ("../bootstrap/bootstrap.php");


$database_logs = Database_Logs::getInstance ();


// Security: The script runs from the cli SAPI only.
if (php_sapi_name () != "cli") {
  $database_logs->log ("Fatal: export/esword.php only runs through the cli SAPI", Filter_Roles::ADMIN_LEVEL);
  die;
}


ignore_user_abort (true);
set_time_limit (0);


// The input parameters.
$bible = $argv [1];
$force = $argv [2];


// Create folder for the export.
$directory = Export_Logic::bibleDirectory ($bible) . "/esword";
if (!file_exists ($directory)) mkdir ($directory, 0777, true);


// Filename for the export.
$filename = "$directory/$bible.bblx";


// If no update is forced, if the files are already there, bail out.
if (!$force) {
  if (!file_exists ($filename)) $force = true;
}
if (!$force) return;


$database_config_general = Database_Config_General::getInstance ();
$database_bibles = Database_Bibles::getInstance ();
$database_books = Database_Books::getInstance ();


$stylesheet = $database_config_general->getExportStylesheet ();


$filter_text_bible = new Filter_Text ($bible);
$filter_text_bible->esword_text = new Esword_Text ($bible);
$books = $database_bibles->getBooks ($bible);
foreach ($books as $book) {
  $chapters = $database_bibles->getChapters ($bible, $book);
  foreach ($chapters as $chapter) {
    $chapter_data = $database_bibles->getChapter ($bible, $book, $chapter);
    $chapter_data = trim ($chapter_data);
    $filter_text_bible->addUsfmCode ($chapter_data);
  }
}
$filter_text_bible->run ($stylesheet);
$filter_text_bible->esword_text->finalize ();
$filter_text_bible->esword_text->createModule ($filename);


$database_logs->log (gettext ("Saved to eSword") . " $bible", Filter_Roles::TRANSLATOR_LEVEL);


?>
